import java.io.FileWriter;
import java.io.IOException;
import java.io.PrintWriter;

public class GlobalExceptionLogger {

    public static void main(String[] args) {
        // Set up global exception handler
        Thread.setDefaultUncaughtExceptionHandler((thread, throwable) -> {
            logException(throwable);
        });

        // Sample code that throws an unhandled exception
        System.out.println("Program started.");

        int result = divide(10, 0);  // This will cause ArithmeticException

        System.out.println("Result: " + result);
    }

    // Method that may throw an exception
    public static int divide(int a, int b) {
        return a / b;  // division by zero triggers an exception
    }

    // Method to log exceptions to a file
    public static void logException(Throwable throwable) {
        try (PrintWriter writer = new PrintWriter(new FileWriter("error.log", true))) {
            writer.println("----- Exception Occurred -----");
            writer.println("Thread: " + Thread.currentThread().getName());
            writer.println("Exception: " + throwable);
            for (StackTraceElement element : throwable.getStackTrace()) {
                writer.println("\tat " + element);
            }
            writer.println();  // Blank line for separation
        } catch (IOException e) {
            System.err.println("Failed to log exception: " + e.getMessage());
        }
    }
}
